@@ -54,10 +54,10 @@ class CollapseColumnBase(tables.Column):
     def __init__(
         self, 
         *args, 
-        label='Show', label_accessor=None, label_extra='', style=None, nowrap=False,
+        label='Show', label_accessor=None, label_extra='', style=None, nowrap=False, orderable=False,
         **kwargs   
     ):
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, orderable=orderable, **kwargs)
         self.label = label
         self.label_accessor = label_accessor
         self.label_extra = label_extra
@@ -104,6 +104,59 @@ class CollapseColumnBase(tables.Column):
         else:
             return ''  
 
+class CollapseDictColumn(CollapseColumnBase):
+    """Custom django-tables2 column that will render a dictionary in a collapsable div.
+
+    Args:
+        *args: passed to CollapseColumnBase
+        sort_by: None, 'key' or 'value' determines what to sort the dictionary by, defaults to None. keys and values will be pandas astype('string')
+        ascending: bool that sorts keys/values ascending (True) or descending (False). Default = True
+        na_position: 'first' or 'last' places records with null values up front or at end respectively
+        **kwargs: passed to CollapseColumnBase
+    """    
+      
+    def __init__(
+        self, *args, 
+        sort_by = None, 
+        ascending = True, 
+        na_position = 'last', 
+        to_html_kwargs = None, 
+        to_html_kwargs_extra = None, 
+        **kwargs
+    ):                
+        super().__init__(*args, **kwargs)
+        assert sort_by in [None, 'key', 'value'], 'Invalid sort_by arg. Options are None, key or value'
+        self.sort_by = sort_by
+        self.ascending = ascending
+        self.na_position = na_position
+        if to_html_kwargs==None:
+            self.to_html_kwargs = dict(
+                classes = ['table-bordered', 'table-striped', 'table-sm'],
+                index=False, justify='left'
+            )                    
+        else: 
+            self.to_html_kwargs = to_html_kwargs
+        self.to_html_kwargs_extra = {} if to_html_kwargs_extra==None else to_html_kwargs_extra
+        self.to_html_kwargs.update(self.to_html_kwargs_extra)
+        
+    def render(self, value, record):
+        val = self.get_dictionary_val(value=value)        
+        return self.final_render(value=value, record=record, val=val)
+
+    def get_dictionary_val(self, value):
+        if isna(value):
+            value = {}        
+        if type(value) != dict:
+            value = json.loads(value)
+        df = DF(Series(value), columns=['value'])
+        df = df.reset_index().rename(columns={'index':'key'})
+        if self.sort_by:
+            df = df.astype(
+                {'value':'string','key':'string'}
+            ).sort_values(self.sort_by, ascending=self.ascending, na_position=self.na_position)
+        df_html = df.to_html(**self.to_html_kwargs)
+        return f'<div style={self.get_style()}>{df_html}</div>'
+
 class CollapseDataFrameColumn(CollapseColumnBase):
     """Custom django-tables2 column that will render a queryset as a pandas.DataFrame using the 
         pandas.DataFrame.to_html method in a collapsable div.
@@ -184,7 +237,7 @@ class CollapseDataFrameColumn(CollapseColumnBase):
         ''' method applies user passed kwargs/args to qs methods '''
         qs = value.filter(
             *self.filter_args, **self.filter_kwargs
-        ).order_by(*self.order_by_args)
+        )
         if self.use_read_frame == False:
             if self.group_by:
                 qs = qs.values(
@@ -198,6 +251,7 @@ class CollapseDataFrameColumn(CollapseColumnBase):
                 ).values(
                     *self.values_args, **self.values_kwargs
                 )
+        qs = qs.order_by(*self.order_by_args)
         return qs if self.limit==None else qs[:self.limit]
 
     def get_df_html(self, qs):
@@ -217,8 +271,6 @@ class CollapseDataFrameColumn(CollapseColumnBase):
             val= self.get_df_html(qs)
         return self.final_render(value=value, record=record, val=val)
 
-
-
 class CollapseColumn(CollapseColumnBase):
     ''' Column is meant for columns that have lots of data in each cell to make viewing cleaner'''
 
@@ -305,6 +357,7 @@ def get_background(value, record, table, bound_column):
         w = 100*val/max
     style_str = f'background:linear-gradient(90deg, {bound_column.column.color} {w}%, transparent {w}%)'
     return style_str
+
 class BarChartColumn(tables.Column):
     def __init__(
         self, *args,
@@ -342,7 +395,6 @@ class BarChartColumn(tables.Column):
             value = 0
         return value
 
-
 class LastChangeDateColumn(tables.Column):
     ''' This Column can be used with tables that have a model defined and 
     are using django simple-history to track changes'''
@@ -367,7 +419,6 @@ class LastChangeUserColumn(tables.Column):
                 return 'Automated'
             return user.employee
 
-
 class LastChangeTypeColumn(tables.Column):
     ''' This Column can be used with tables that have a model defined and 
     are using django simple-history to track changes'''
